@@ -24,11 +24,10 @@ class DbfsLocation:
 
     @classmethod
     def from_str(cls, val: str) -> "DbfsLocation":
-
         if val[:6] not in ["dbfs:/", "/dbfs/"]:
             raise ValueError("Invalid dbfs path")
 
-        result = cls(base=val[:6])
+        return cls(base=val[:6])
 
     @remote.setter
     def set_remote(self, remote: str) -> None:
